Package: multiDEGGs
Title: Multi-Omic Differentially Expressed Gene-Gene Pairs
Version: 1.2.1
Authors@R: 
    c(person(given = "Elisabetta",
          family = "Sciacca",
          role = c("aut", "cre", "cph"),
          email = "e.sciacca@qmul.ac.uk",
          comment = c(ORCID = "0000-0001-7525-1558")),
      person(given = "Myles",family = "Lewis",
          role = c("ctb"),
          email = "myles.lewis@qmul.ac.uk",
          comment = c(ORCID = "0000-0001-9365-5345")))
Maintainer: Elisabetta Sciacca <e.sciacca@qmul.ac.uk>
Description: Performs multi-omic differential network 
      analysis by revealing differential interactions between molecular entities
      (genes, proteins, transcription factors, or other biomolecules) across the
      omic datasets provided. 
      For each omic dataset, a differential network is constructed where
      links represent statistically significant differential interactions between 
      entities. These networks are then integrated into a comprehensive visualization
      using distinct colors to distinguish interactions from different omic layers.
      This unified display allows interactive exploration of cross-omic
      patterns, such as differential interactions present at both transcript and
      protein levels. For each link, users can access differential statistical 
      significance metrics (p values or adjusted p values, calculated via robust or 
      traditional linear regression with interaction term) and differential regression
      plots.  
      The methods implemented in this package are described in Sciacca et al. (2023)
      <doi:10.1093/bioinformatics/btad192>.
License: GPL-3
Encoding: UTF-8
LazyData: true
LazyDataCompression: gzip
RoxygenNote: 7.3.3
Language: en-gb
URL: https://github.com/elisabettasciacca/multiDEGGs/,
        https://elisabettasciacca.github.io/multiDEGGs/
BugReports: https://github.com/elisabettasciacca/multiDEGGs/issues
Suggests: kernlab, nestedcv, pls, qvalue, randomForest, ranger,
        testthat (>= 3.0.0)
Imports: DT, grDevices, graphics, knitr, MASS, magrittr, methods,
        parallel, pbapply, pbmcapply, rmarkdown, sfsmisc, shiny,
        shinydashboard, stats, utils, visNetwork
Depends: R (>= 4.4.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-10 09:09:30 UTC; elisabetta
Author: Elisabetta Sciacca [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-7525-1558>),
  Myles Lewis [ctb] (ORCID: <https://orcid.org/0000-0001-9365-5345>)
Repository: CRAN
Date/Publication: 2026-04-10 09:40:02 UTC
Built: R 4.5.2; ; 2026-04-10 11:19:43 UTC; unix
