# Generated by roxygen2: do not edit by hand

S3method(predict,multiDEGGs_filter)
S3method(predict,multiDEGGs_filter_combined)
export(.predict_multiDEGGs)
export(View_diffNetworks)
export(get_diffNetworks)
export(get_multiOmics_diffNetworks)
export(get_sig_deggs)
export(multiDEGGs_combined_filter)
export(multiDEGGs_filter)
export(plot_regressions)
import(knitr)
import(rmarkdown)
importFrom(MASS,rlm)
importFrom(grDevices,adjustcolor)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,boxplot)
importFrom(graphics,legend)
importFrom(graphics,mtext)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,text)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(sfsmisc,f.robftest)
